TxnParams class

Transaction parameters. Matches: TxnParams in native SDK.

Constructors

TxnParams({required String amount, String? orderId, Transaction? originalTransaction})

Properties

amount String
final
hashCode int
The hash code for this object.
no setterinherited
orderId String?
final
originalTransaction Transaction?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setOriginalTransaction(Transaction txn) → dynamic
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited