RemoteAccess class
DigetSposPlugin.RemoteChannel — local network remote access. Matches: DigetSposPlugin.RemoteChannel in native SDK.
Constructors
- RemoteAccess.create()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
LocalNetwork(
{required int port, required double timeout}) → LocalNetworkBuilder - Convenience: DigetSposPlugin.RemoteChannel.LocalNetwork(...)
-
localNetwork(
{required int port, required double timeout}) → LocalNetworkBuilder - Configure and return a local network channel builder. Usage: DigetSposPlugin.RemoteChannel.LocalNetwork(port: 8080, timeout: 30.0).open()
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited